@@ -4,6 +4,9 @@ import sys
 if sys.maxsize > 2**32:
     import ModelIO
 
+    class TestMDLTypesHelper (ModelIO.NSObject):
+        def objectAtIndexedSubscript_(self, i): return 1
+
     class TestMDLTypes (TestCase):
         def testConstants(self):
             self.assertIsInstance(ModelIO.kUTTypeAlembic, unicode)
@@ -11,6 +14,10 @@ if sys.maxsize > 2**32:
             self.assertIsInstance(ModelIO.kUTTypePolygon, unicode)
             self.assertIsInstance(ModelIO.kUTTypeStereolithography, unicode)
 
+            self.assertEqual(ModelIO.MDLDataPrecisionUndefined, 0)
+            self.assertEqual(ModelIO.MDLDataPrecisionFloat, 1)
+            self.assertEqual(ModelIO.MDLDataPrecisionDouble, 2)
+
             self.assertEqual(ModelIO.MDLIndexBitDepthInvalid, 0)
             self.assertEqual(ModelIO.MDLIndexBitDepthUInt8, 8)
             self.assertEqual(ModelIO.MDLIndexBitDepthUint8, 8)
@@ -38,6 +45,9 @@ if sys.maxsize > 2**32:
             objc.protocolNamed('MDLComponent')
             objc.protocolNamed('MDLObjectContainerComponent')
 
+        def testMethods(self):
+            self.assertArgHasType(TestMDLTypesHelper.objectAtIndexedSubscript_, 0, objc._C_NSUInteger)
+
         @expectedFailure
         def testStructs(self):
             self.fail("MDLAxisAlignedBoundingBox is SIMD type")
